@@ -17,9 +17,9 @@
 #include "sord/sordmm.hpp"
 
 int
-main(int argc, char** argv)
+main()
 {
 	Sord::World world;
-	Sord::Model model(world);
+	Sord::Model model(world, "http://example.org/");
 	return 0;
 }
